/*
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
************************** 602_Programm_Sonderzeichen *************************
-------------------------------------------------------------------------------
******************************* main.c ** V1.1 ********************************
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
 Abbilden von Sonderzeichen auf dem LCD
 Zusaetzliche Header..: keine
 Module.(*.c und *.h).: application, lcd_2wire, num_conversion
 Benoetigte Hardware..: Testboard, 20x4-LCD und 2-Draht-LCD-Interface
 Version..............: 1.1
 Compiler.............: CodeVisionAVR
 Chip.................: ATmega88
 Datum................: Juni 2009
 Autor................: Alwin Lenck (ALE23) basierend auf dem Projekt 
                        2-Draht-LCD von Udo Juerss
-------------------------------------------------------------------------------
In diesem Beispiel werden Sonderzeichen konstruiert und auf dem 20x4-LCD
abgebildet

Anschluesse des 20x4-LCD:
CLOCK................: PB1 (kann geaendert werden in application.h)
DATA.................: PB2 (kann geaendert werden in application.h)

-------------------------------------------------------------------------------
 Verwendete Typ-Synonyme (werden in typedefs.h definiert):
-------------------------------------------------------------------------------
 U08    unsigned char
 fpU08  unsigned char __flash *...        // Pointer auf unsigned char im FLASH
*/

//-----------------------------------------------------------------------------
// Header-Dateien einfuegen:
//-----------------------------------------------------------------------------
#include "application.h"                  // Initialisierung der Anwendung
#include "lcd_2wire.h"                    // Initialisierung des 2Draht-LCDs
#include "num_conversion.h"               // Initialisierung der Konvertierung

//-----------------------------------------------------------------------------
// Globale Variablen:
//-----------------------------------------------------------------------------
fpU08 LCD_STR[4] =                        // Display text
{
  ("Grad-Zeichen:      a"),
  ("Schachbrett:       b"),
  ("Ohm-Zeichen:       c"),
  ("LE-Zeichen:        d")
};

U08 n;
__flash U08 _SIGN0[8] =
{
  0x0C,0x12,0x12,0x0C,0x00,0x00,0x00,0x00 // Grad-Zeichen
};
__flash U08 _SIGN1[8] =
{
  0x0A,0x15,0x0A,0x15,0x0A,0x15,0x0A,0x00 // Schachbrett-Zeichen
};
__flash U08 _SIGN2[8] =
{
  0x00,0x0E,0x11,0x11,0x11,0x0A,0x1B,0x00 // Ohm-Zeichen
};
__flash U08 _SIGN3[8] =
{
  0x17,0x14,0x16,0x14,0x17,0x10,0x1F,0x00 // LE-Zeichen
};

//-----------------------------------------------------------------------------
// Hauptprogramm main
//-----------------------------------------------------------------------------
void main(void)
{
// Die folgenden 2 Anweisungen stammen vom AVR-Projekt 2-Draht-LCD
  // Setzen des System-Taktes (CPU-Clock),
  // Ausschalten nicht benutzter Hardware-Module
  app_init();                      // Initialisierung der Anwendung

  // Definition von Prototypen fuer LCD-Ausgabe-Funktionen usw.
  lcd_init();                      // Initialisierung des LCD-Interfaces

  // Setzen der Sonder-Zeichen im LCD-Controller
  lcd_download_char_from_rom(0,(fpU08)&_SIGN0);  // auf Grad-Zeichen
  lcd_download_char_from_rom(1,(fpU08)&_SIGN1);  // auf Schachbrett
  lcd_download_char_from_rom(2,(fpU08)&_SIGN2);  // auf Ohm-Zeichen
  lcd_download_char_from_rom(3,(fpU08)&_SIGN3);  // auf LE-Zeichen

  while (true)                                   // Endlosschleife
  {
    for (n = 0; n < 4; n++)                      // Schreibe Display-Text
    {
      lcd_goto_xy(0,n);                          // Setze Cursor an LCD-Anfang
      lcd_write_flash_str((fpU08)LCD_STR[n]);    // Begleittext der Zeile
      lcd_goto_xy(19,n);                         // An das Ende der Zeile
      lcd_write_char(n);                         // Sonder-Zeichen
                                                 // n = Adresse im CGRAM
    }
  }
}
//-----------------------------------------------------------------------------
